import 'package:flutter/material.dart';
import 'package:shared_preferences/shared_preferences.dart';

class ThemeStore {
  static late SharedPreferences sharedPreferences; // 持久化存储实例
  static const _mode = "theme_mode"; // 用于持久化存储的key

  /// 将 [ThemeMode] 映射成 [int] 类型
  static const Map<int, ThemeMode> modeMap = {
    0: ThemeMode.system,
    1: ThemeMode.light,
    2: ThemeMode.dark,
  };

  /// 初始化
  static Future init() async {
    sharedPreferences = await SharedPreferences.getInstance();
  }

  /// 设置主题模式
  static Future setThemeMode(ThemeMode themeMode) async {
    return await sharedPreferences.setInt(
        _mode, modeMap.entries.firstWhere(((element) => element.value == themeMode)).key);
  }

  /// 获取主题模式
  static ThemeMode getThemeMode() {
    int? result = sharedPreferences.getInt(_mode);
    return modeMap[modeMap.keys.contains(result) ? result : 0]!;
  }
}
